summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcsgedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcsgedit.h')
-rw-r--r--kpovmodeler/pmcsgedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmcsgedit.h b/kpovmodeler/pmcsgedit.h
index 1ec5d205..9e371a40 100644
--- a/kpovmodeler/pmcsgedit.h
+++ b/kpovmodeler/pmcsgedit.h
@@ -39,9 +39,9 @@ class PMCSGEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMCSGEdit with tqparent and name
*/
- PMCSGEdit( TQWidget* tqparent, const char* name = 0 );
+ PMCSGEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMCSGEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMCSGEdit with tqparent and name
+ * Creates a PMCSGEdit with parent and name
*/